package ortools_solvers

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
OCaml interface for invoking Google OR-Tools

OR-Tools is an open source software suite for optimization, tuned for tackling the world's toughest problems in vehicle routing, flows, integer and linear programming, and constraint programming.

This interface allows for calling the following solvers.

Type

Solver

Interface

Model

Constraint Optimization

CP-SAT

Ortools_solvers.Sat

Ortools.Sat